pyparsing.Recipes

Module pyparsing :: Class Recipes |
[frames] | no frames]

# Class Recipes

source code

Here are some common low-level expressions that may be useful in jump-starting your parser development:

Instance Methods
convertToInteger(t) Parse action for converting parsed integers to Python int | source code
convertToFloat(t) Parse action for converting parsed numbers to Python float | source code

Class Variables
| integer = `integer`
| signedInteger = `signed integer`
| real = `real number`
| sciReal = `real number with scientfic notation`
| numeric = `{real number with scientfic notation | real number |`...``
| number = `number`
| identifier = `identifier`

Class Variable Details

  ### numeric Value:
      {real number with scientfic notation | real number | integer | signed
      integer}